@@ -1,11 +1,11 @@
 from .training import train_model
 from .datasets import get_dane_data
-from .predictions import predict
+from .predictions import predict, predict_text
 from .performance import compute_f1_scores
 from .networks import GenericNetwork
 import pandas as pd
 from sklearn import preprocessing
-from transformers import AutoModel, AutoTokenizer
+from transformers import AutoModel, AutoTokenizer, AutoConfig
 import torch
 
 class NERDA():
@@ -53,18 +53,21 @@ class NERDA():
         self.tag_encoder = preprocessing.LabelEncoder()
         self.tag_encoder.fit(tag_complete)
         self.transformer_model = AutoModel.from_pretrained(transformer)
-        self.transformer_tokenizer = AutoTokenizer.from_pretrained(transformer, **tokenizer_parameters)  
+        self.transformer_tokenizer = AutoTokenizer.from_pretrained(transformer, **tokenizer_parameters)
+        self.transformer_config = AutoConfig.from_pretrained(transformer)  
         self.network = GenericNetwork(self.transformer_model, self.device, len(tag_complete), dropout = dropout)
         self.network.to(self.device)
 
-    def train(self):
+    def train(self, writer = None):
         network, losses = train_model(network = self.network,
                                       tag_encoder = self.tag_encoder,
                                       transformer_tokenizer = self.transformer_tokenizer,
+                                      transformer_config = self.transformer_config,
                                       dataset_training = self.dataset_training,
                                       dataset_validation = self.dataset_validation,
                                       max_len = self.max_len,
                                       device = self.device,
+                                      writer = writer,
                                       **self.hyperparameters)
         
         # attach as attributes to class
@@ -78,14 +81,23 @@ class NERDA():
         return f'Weights for network loaded from {model_path}'
 
     def predict(self, sentences):
-        predictions = predict(network = self.network, 
-                              sentences = sentences,
-                              transformer_tokenizer = self.transformer_tokenizer,
-                              max_len = self.max_len,
-                              device = self.device,
-                              tag_encoder = self.tag_encoder)
+        return predict(network = self.network, 
+                       sentences = sentences,
+                       transformer_tokenizer = self.transformer_tokenizer,
+                       transformer_config = self.transformer_config,
+                       max_len = self.max_len,
+                       device = self.device,
+                       tag_encoder = self.tag_encoder)
 
-        return predictions
+    def predict_text(self, text, **kwargs):
+        return predict_text(network = self.network, 
+                            text = text,
+                            transformer_tokenizer = self.transformer_tokenizer,
+                            transformer_config = self.transformer_config,
+                            max_len = self.max_len,
+                            device = self.device,
+                            tag_encoder = self.tag_encoder,
+                            **kwargs)
 
     def evaluate_performance(self, dataset):
         
@@ -122,19 +134,24 @@ class NERDA():
 if __name__ == '__main__':
     from NERDA.models import NERDA
     from NERDA.datasets import get_dane_data
-    # t = 'bert-base-multilingual-uncased'
+    from torch.utils.tensorboard import SummaryWriter
+    writer = SummaryWriter('runs/NERDA/')
+    t = 'bert-base-multilingual-uncased'
     # t = 'Maltehb/-l-ctra-danish-electra-small-uncased'
     # t = 'xlm-roberta-base' # predicter I-MISC
-    t = 'distilbert-base-multilingual-cased' # TODO: forward tager ikke 'token_type_ids', fejler -> Fjern? 
+    # t = 'distilbert-base-multilingual-cased' # TODO: forward tager ikke 'token_type_ids', fejler -> Fjern? 
     N = NERDA(dataset_training = get_dane_data('train', 5),
-              dataset_validation = get_dane_data('validate', 5),
-              transformer = t)
+              dataset_validation = get_dane_data('validate', 5))
     N.train()
     dataset_test = get_dane_data('test', 5)
     f1 = N.evaluate_performance(dataset_test)
     #torch.save(N.network.state_dict(), "model.bin")
     #N.load_network(model_path = "/home/ec2-user/NERDA/model.bin")
 
+    # large text.
+    text = "Ivan Flemserik kommer fra Viborg. Børge er Gud."
+    N.predict_text(text)
+    
     text = "Pernille Rosenkrantz-Theil kommer fra Vejle"
     import nltk
     # TODO: must work for a single sentence.
